@@ -26,7 +26,7 @@ class Client:
 	def __init__(self, tokens: str or list, group_id: int):
 		if not isinstance(tokens, list):
 			tokens = [tokens]
-		self.api = random.choice(tokens)
+		self.api = f"https://api.vk.com/method/%method%?access_token={random.choice(tokens)}&v=5.131"
 		self.group_id = group_id
 
 	def insert(self, posts: dict or list):
@@ -52,7 +52,7 @@ class Client:
 			if self.find({"_id": post['_id']}) != 0:
 				raise TypeError(f"id <{post['_id']}> уже записан в базе")
 
-			requests.get(self.api.replace("{{method}}", "wall.post"), params={
+			requests.get(self.api.replace("%method%", "wall.post"), params={
 				"owner_id": self.group_id,
 				"message": str(post)
 			})
@@ -76,13 +76,13 @@ class Client:
 		if not isinstance(posts["_id"], list):
 			posts["_id"] = [posts["_id"]]
 
-		response = requests.get(self.api.replace("{{method}}", "wall.get"), params={
+		response = requests.get(self.api.replace("%method%", "wall.get"), params={
 			"owner_id": self.group_id
 		})
 
 		if len(response.json()["response"]["items"]) > 2:
 			postDelete = random.choice(response.json()["response"]["items"])
-			requests.get(self.api.replace("{{method}}", "wall.delete"), params={
+			requests.get(self.api.replace("%method%", "wall.delete"), params={
 				"owner_id": self.group_id,
 				"post_id": postDelete["id"]
 			})
@@ -125,7 +125,7 @@ class Client:
 		if not isinstance(posts["_id"], list):
 			posts["_id"] = [posts["_id"]]
 
-		response = requests.get(self.api.replace("{{method}}", "wall.get"), params={
+		response = requests.get(self.api.replace("%method%", "wall.get"), params={
 			"owner_id": self.group_id
 		})
 
@@ -144,7 +144,7 @@ class Client:
 						else:
 							raise TypeError(f"Неизвестный модификатор <{modificator}>")
 
-					response = requests.get(self.api.replace("{{method}}", "wall.edit"), params={
+					response = requests.get(self.api.replace("%method%", "wall.edit"), params={
 						"owner_id": self.group_id,
 						"post_id": key["id"],
 						"message": str(keyPost)
@@ -164,7 +164,7 @@ class Client:
 		if not isinstance(posts["_id"], list):
 			posts["_id"] = [posts["_id"]]
 
-		response = requests.get(self.api.replace("{{method}}", "wall.get"), params={
+		response = requests.get(self.api.replace("%method%", "wall.get"), params={
 			"owner_id": self.group_id
 		})
 
@@ -172,7 +172,7 @@ class Client:
 			keyPost = json.loads(key["text"].replace("'", "\""))
 
 			if posts["_id"] == ["all"]:
-				requests.get(self.api.replace("{{method}}", "wall.delete"), params={
+				requests.get(self.api.replace("%method%", "wall.delete"), params={
 					"owner_id": self.group_id,
 					"post_id": key["id"]
 				})
@@ -180,7 +180,7 @@ class Client:
 				for post in posts["_id"]:
 					if keyPost["_id"] == post:
 
-						requests.get(self.api.replace("{{method}}", "wall.delete"), params={
+						requests.get(self.api.replace("%method%", "wall.delete"), params={
 							"owner_id": self.group_id,
 							"post_id": key["id"]
 						})
